@@ -92,7 +92,7 @@ class WaifuAioClient:
         infos= await self._make_request(f"{APIBaseURL}{type_}/{tag}/",'get',params=params,headers=None if not headers else headers)
         if raw:
             return infos
-        return infos.get('url')
+        return [im.get('url') for im in infos.get('tags')[0].get('images')] if many else infos.get('tags')[0].get('images')[0].get('url')
 
 
     async def _fetchgallery(self, user_id, toggle, insert, delete, token):
